pub struct BuildState {
pub blob_service: Arc<dyn BlobService>,
pub directory_service: Arc<dyn DirectoryService>,
pub path_info_service: Arc<dyn PathInfoService>,
pub nar_calculation_service: Arc<dyn NarCalculationService>,
build_service: Arc<dyn BuildService>,
pub fetcher: Fetcher<Arc<dyn BlobService>, Arc<dyn DirectoryService>, Arc<dyn PathInfoService>, Arc<dyn NarCalculationService>>,
pub known_paths: RefCell<KnownPaths>,
}Fields
blob_service: Arc<dyn BlobService>directory_service: Arc<dyn DirectoryService>path_info_service: Arc<dyn PathInfoService>nar_calculation_service: Arc<dyn NarCalculationService>build_service: Arc<dyn BuildService>fetcher: Fetcher<Arc<dyn BlobService>, Arc<dyn DirectoryService>, Arc<dyn PathInfoService>, Arc<dyn NarCalculationService>>known_paths: RefCell<KnownPaths>Implementations
Sourceimpl BuildState
impl BuildState
pub fn new( blob_service: Arc<dyn BlobService>, directory_service: Arc<dyn DirectoryService>, path_info_service: Arc<dyn PathInfoService>, nar_calculation_service: Arc<dyn NarCalculationService>, build_service: Arc<dyn BuildService>, hashed_mirrors: Vec<Url>, ) -> Self
Sourcepub async fn store_path_to_path_info(
&self,
store_path: &StorePathRef<'_>,
sub_path: &Path,
) -> Result<Option<PathInfo>>
pub async fn store_path_to_path_info( &self, store_path: &StorePathRef<'_>, sub_path: &Path, ) -> Result<Option<PathInfo>>
for a given [StorePath] and additional [snix_castore::Path] inside the store path,
look up the [PathInfo], and if it exists, and then uses
[descend_to] to return the [snix_castore::Node] specified by sub_path.
In case there is no PathInfo yet, we check “self.known_paths” (learnt by the evaluator)
- If there’s a fetch, we do that and return the resulting PathInfo.
- If there’s a Derivation, we build it and return the resulting PathInfo. To build it, we need to do a function call to ourselves with all inputs of that Derivation, which will trigger fetches / builds of inputs, recursively.
This should be replaced with a proper scheduler knowing about a partial subgraph at some point, because this design doesn’t allow concurrent builds yet.